@@ -1,7 +1,10 @@
 """Test running of scripts with various modes and options."""
 
+import importlib
 import io
 import os
+import sys
+from unittest import mock
 
 import pytest
 
@@ -87,7 +90,11 @@ def test_return_None(script_runner):
     # One commonly available script that returns None from the entry point
     # function is easy_install so we use it here.
 
-    result = script_runner.run('easy_install', '-h')
+    try:
+        result = script_runner.run('easy_install', '-h')
+    except FileNotFoundError:
+        # No easy install. Just skip.
+        return
     assert result.success
     assert '--verbose' in result.stdout
 
@@ -266,3 +273,46 @@ def test_script(script_runner):
     assert result.success
     assert 'the answer is 42' not in result.stdout
     assert 'Running console script' not in result.stdout
+
+
+class MockEntryPoint:
+    def __init__(self, exec_path):
+        self.exec_path = exec_path
+        self.module = None
+
+    def load(self):
+        base, module = os.path.split(self.exec_path)
+        module_name, _ = os.path.splitext(module)
+        sys.path.append(base)
+        self.module = importlib.import_module(module_name)
+        sys.path.pop(-1)
+        return self.module.run
+
+
+@pytest.mark.script_launch_mode('inprocess')
+def test_global_logging(tmpdir, console_script, script_runner):
+    """Load global values when executing from pkg_resources"""
+    test = tmpdir.join('test_entry_point.py')
+    test.write(
+        """
+import logging
+
+logging.basicConfig(level=logging.INFO)
+LOGGER = logging.getLogger(__name__)
+
+
+def run():
+    LOGGER.debug('DEBUG')
+    LOGGER.info('INFO')
+    LOGGER.warning('WARNING')
+        """
+    )
+
+    with mock.patch(
+        'pkg_resources.iter_entry_points',
+        mock.MagicMock(return_value=[MockEntryPoint(str(test))]),
+    ):
+        result = script_runner.run(str(console_script))
+        assert result.success
+        assert 'INFO:test_entry_point:INFO\n' in result.stderr
+        assert 'DEBUG\n' not in result.stderr
